emo

package module
v0.0.0-...-28f2602 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 7 Imported by: 15

README

Emo

Emoji based semantic scoped debugging for Go, Python, Typescript/Javascript and Dart

Documentation

Complete events list

How to contribute

To add more emojis and methods please edit the codegen/ref.json file. The code in all languages is generated in from this file.

Generate the code

Run the codegen tools to build up the functions from the codegen/ref.json file.

Build the Go library
make go

This will regenerate the generated.go file

Build the Python library
make py

This will regenerate the lang/python/pyemo/emo_gen.py file

Build the Typescript library
make ts

This will regenerate the lang/typescript/src/emo_gen.ts file

Build the Dart library
make dart

This will regenerate the lang/dart/lib/src/debug.dart file

Build all languages at once
make all
Generate the doc

Regenerate the complete events list:

make doc

Development

Run the tests
make test

Visualize the tests coverage:

make cov

Documentation

Index

Constants

This section is empty.

Variables

var DefaultZone = Zone{
	Name:      "",
	Verbose:   Auto,
	StackInfo: Auto,
	Hook:      nil,
}

DefaultZone allows to use emo without having to create a new zone. DefaultZone defines the default values.

Functions

func Fatal

func Fatal(args ...any)

func Fatalf

func Fatalf(format string, v ...any)

func GlobalColoring

func GlobalColoring(enable bool)

GlobalColoring enables/disables the coloring of the event print.

func GlobalHook

func GlobalHook(hook func(Event))

SetHook sets the callback function to be triggered by all zones.

func GlobalStackInfo

func GlobalStackInfo(enable bool)

GlobalStackInfo enables/disables the call stack information for all zones having StackInfo=Auto.

func GlobalTimestamp

func GlobalTimestamp(enable bool)

GlobalTimestamp enables the insertion of a date/time timestamp for each event print. To disable use:

emo.GlobalTimestamp(false)

func GlobalTracing

func GlobalTracing(enable bool)

GlobalTracing enables the print of the Trace() events.

func GlobalVerbosity

func GlobalVerbosity(enable bool)

GlobalVerbosity controls the verbose mode for all zones having Verbose=Auto.

func ObjectInfo

func ObjectInfo(args ...any)

ObjectInfo prints elements list for debugging purpose.

func Panic

func Panic(args ...any)

func Panicf

func Panicf(format string, v ...any)

Types

type Event

type Event struct {
	Emoji   string
	Zone    Zone
	IsError bool
	Args    []any
	From    string
	File    string
	Line    int
	// contains filtered or unexported fields
}

Event : base emo event.

func AccessToken

func AccessToken(args ...any) Event

func AccessTokenf

func AccessTokenf(format string, v ...any) Event

func Aconstructor

func Aconstructor(args ...any) Event

func AconstructorError

func AconstructorError(args ...any) Event

func AconstructorErrorf

func AconstructorErrorf(format string, v ...any) Event

func Aconstructorf

func Aconstructorf(format string, v ...any) Event

func ArrowDown

func ArrowDown(args ...any) Event

func ArrowDownf

func ArrowDownf(format string, v ...any) Event

func ArrowIn

func ArrowIn(args ...any) Event

func ArrowInf

func ArrowInf(format string, v ...any) Event

func ArrowOut

func ArrowOut(args ...any) Event

func ArrowOutf

func ArrowOutf(format string, v ...any) Event

func ArrowUp

func ArrowUp(args ...any) Event

func ArrowUpf

func ArrowUpf(format string, v ...any) Event

func Bad

func Bad(args ...any) Event

func BadError

func BadError(args ...any) Event

func BadErrorf

func BadErrorf(format string, v ...any) Event

func Badf

func Badf(format string, v ...any) Event

func Build

func Build(args ...any) Event

func BuildError

func BuildError(args ...any) Event

func BuildErrorf

func BuildErrorf(format string, v ...any) Event

func Buildf

func Buildf(format string, v ...any) Event

func Check

func Check(args ...any) Event

func Checkf

func Checkf(format string, v ...any) Event

func Data

func Data(args ...any) Event

func DataError

func DataError(args ...any) Event

func DataErrorf

func DataErrorf(format string, v ...any) Event

func Dataf

func Dataf(format string, v ...any) Event

func Debug

func Debug(args ...any) Event

func Debugf

func Debugf(format string, v ...any) Event

func Decrypt

func Decrypt(args ...any) Event

func DecryptError

func DecryptError(args ...any) Event

func DecryptErrorf

func DecryptErrorf(format string, v ...any) Event

func Decryptf

func Decryptf(format string, v ...any) Event

func Delete

func Delete(args ...any) Event

func DeleteError

func DeleteError(args ...any) Event

func DeleteErrorf

func DeleteErrorf(format string, v ...any) Event

func Deletef

func Deletef(format string, v ...any) Event

func Down

func Down(args ...any) Event

func DownError

func DownError(args ...any) Event

func DownErrorf

func DownErrorf(format string, v ...any) Event

func Downf

func Downf(format string, v ...any) Event

func Encrypt

func Encrypt(args ...any) Event

func EncryptError

func EncryptError(args ...any) Event

func EncryptErrorf

func EncryptErrorf(format string, v ...any) Event

func Encryptf

func Encryptf(format string, v ...any) Event

func Error

func Error(args ...any) Event

func Errorf

func Errorf(format string, v ...any) Event

func Found

func Found(args ...any) Event

func Foundf

func Foundf(format string, v ...any) Event

func Function

func Function(args ...any) Event

func FunctionError

func FunctionError(args ...any) Event

func FunctionErrorf

func FunctionErrorf(format string, v ...any) Event

func Functionf

func Functionf(format string, v ...any) Event

func Good

func Good(args ...any) Event

func Goodf

func Goodf(format string, v ...any) Event

func In

func In(args ...any) Event

func InError

func InError(args ...any) Event

func InErrorf

func InErrorf(format string, v ...any) Event

func Inf

func Inf(format string, v ...any) Event

func Info

func Info(args ...any) Event

func Infof

func Infof(format string, v ...any) Event

func Init

func Init(args ...any) Event

func InitError

func InitError(args ...any) Event

func InitErrorf

func InitErrorf(format string, v ...any) Event

func Initf

func Initf(format string, v ...any) Event

func Input

func Input(args ...any) Event

func InputError

func InputError(args ...any) Event

func InputErrorf

func InputErrorf(format string, v ...any) Event

func Inputf

func Inputf(format string, v ...any) Event

func Key

func Key(args ...any) Event

func KeyError

func KeyError(args ...any) Event

func KeyErrorf

func KeyErrorf(format string, v ...any) Event

func Keyf

func Keyf(format string, v ...any) Event

func Line

func Line(args ...any) Event

func LineError

func LineError(args ...any) Event

func LineErrorf

func LineErrorf(format string, v ...any) Event

func Linef

func Linef(format string, v ...any) Event

func NotFound

func NotFound(args ...any) Event

func NotFoundf

func NotFoundf(format string, v ...any) Event

func Ok

func Ok(args ...any) Event

func Okf

func Okf(format string, v ...any) Event

func Out

func Out(args ...any) Event

func OutError

func OutError(args ...any) Event

func OutErrorf

func OutErrorf(format string, v ...any) Event

func Outf

func Outf(format string, v ...any) Event

func Output

func Output(args ...any) Event

func OutputError

func OutputError(args ...any) Event

func OutputErrorf

func OutputErrorf(format string, v ...any) Event

func Outputf

func Outputf(format string, v ...any) Event

func Param

func Param(args ...any) Event

func ParamError

func ParamError(args ...any) Event

func ParamErrorf

func ParamErrorf(format string, v ...any) Event

func Paramf

func Paramf(format string, v ...any) Event

func Print

func Print(args ...any) Event

Warn looks same as Warning, but:

  • Warn is printed even when Verbose=No, and
  • Warn is printed with the call stack info (similar to Error).

func Printf

func Printf(format string, v ...any) Event

func Query

func Query(args ...any) Event

func QueryError

func QueryError(args ...any) Event

func QueryErrorf

func QueryErrorf(format string, v ...any) Event

func Queryf

func Queryf(format string, v ...any) Event

func RefreshToken

func RefreshToken(args ...any) Event

func RefreshTokenf

func RefreshTokenf(format string, v ...any) Event

func RequestGet

func RequestGet(args ...any) Event

func RequestGetError

func RequestGetError(args ...any) Event

func RequestGetErrorf

func RequestGetErrorf(format string, v ...any) Event

func RequestGetf

func RequestGetf(format string, v ...any) Event

func RequestPost

func RequestPost(args ...any) Event

func RequestPostError

func RequestPostError(args ...any) Event

func RequestPostErrorf

func RequestPostErrorf(format string, v ...any) Event

func RequestPostf

func RequestPostf(format string, v ...any) Event

func Result

func Result(args ...any) Event

func Resultf

func Resultf(format string, v ...any) Event

func Save

func Save(args ...any) Event

func SaveError

func SaveError(args ...any) Event

func SaveErrorf

func SaveErrorf(format string, v ...any) Event

func Savef

func Savef(format string, v ...any) Event

func Security

func Security(args ...any) Event

func SecurityError

func SecurityError(args ...any) Event

func SecurityErrorf

func SecurityErrorf(format string, v ...any) Event

func Securityf

func Securityf(format string, v ...any) Event

func SmallArrowDown

func SmallArrowDown(args ...any) Event

func SmallArrowDownf

func SmallArrowDownf(format string, v ...any) Event

func SmallArrowIn

func SmallArrowIn(args ...any) Event

func SmallArrowInf

func SmallArrowInf(format string, v ...any) Event

func SmallArrowOut

func SmallArrowOut(args ...any) Event

func SmallArrowOutf

func SmallArrowOutf(format string, v ...any) Event

func SmallArrowUp

func SmallArrowUp(args ...any) Event

func SmallArrowUpf

func SmallArrowUpf(format string, v ...any) Event

func Start

func Start(args ...any) Event

func StartError

func StartError(args ...any) Event

func StartErrorf

func StartErrorf(format string, v ...any) Event

func Startf

func Startf(format string, v ...any) Event

func State

func State(args ...any) Event

func StateError

func StateError(args ...any) Event

func StateErrorf

func StateErrorf(format string, v ...any) Event

func Statef

func Statef(format string, v ...any) Event

func Stop

func Stop(args ...any) Event

func StopError

func StopError(args ...any) Event

func StopErrorf

func StopErrorf(format string, v ...any) Event

func Stopf

func Stopf(format string, v ...any) Event

func Time

func Time(args ...any) Event

func TimeError

func TimeError(args ...any) Event

func TimeErrorf

func TimeErrorf(format string, v ...any) Event

func Timef

func Timef(format string, v ...any) Event

func Trace

func Trace(args ...any) Event

func Tracef

func Tracef(format string, v ...any) Event

func Transmit

func Transmit(args ...any) Event

func TransmitError

func TransmitError(args ...any) Event

func TransmitErrorf

func TransmitErrorf(format string, v ...any) Event

func Transmitf

func Transmitf(format string, v ...any) Event

func Up

func Up(args ...any) Event

func UpError

func UpError(args ...any) Event

func UpErrorf

func UpErrorf(format string, v ...any) Event

func Update

func Update(args ...any) Event

func UpdateError

func UpdateError(args ...any) Event

func UpdateErrorf

func UpdateErrorf(format string, v ...any) Event

func Updatef

func Updatef(format string, v ...any) Event

func Upf

func Upf(format string, v ...any) Event

func Warn

func Warn(args ...any) Event

Warn looks same as Warning, but:

  • Warn is printed even when Verbose=No, and
  • Warn is printed with the call stack info (similar to Error).

func Warnf

func Warnf(format string, v ...any) Event

func Warning

func Warning(args ...any) Event

func Warningf

func Warningf(format string, v ...any) Event

func (Event) CallHook

func (e Event) CallHook() Event

func (Event) Err

func (e Event) Err() error

Err converts an Event to a standard Go error.

func (*Event) Error

func (e *Event) Error() string

Error is the implementation of the error interface.

func (Event) Message

func (e Event) Message() string

func (Event) Print

func (e Event) Print() Event

func (Event) Stack

func (e Event) Stack(optionalPosition ...int) Event

Stack extracts info from the the call stack info (caller function, file and line number). Then the event may be printed later. The optional parameter allows to change the call stack depth within the call stack.

type ParamType

type ParamType int
const (
	Auto ParamType = 0
	No   ParamType = -1
	Yes  ParamType = 1
)

type Zone

type Zone struct {
	Name      string
	Verbose   ParamType // true => always print ; false => print only when isError
	StackInfo ParamType // StackNo => never print the call stack info, StackAuto => only when Verbose=true and isError
	Hook      func(Event)
}

Zone : base emo zone.

func NewZone

func NewZone(name string) Zone

NewZone : create a zone.

func (Zone) AccessToken

func (zone Zone) AccessToken(args ...any) Event

func (Zone) AccessTokenf

func (zone Zone) AccessTokenf(format string, v ...any) Event

func (Zone) Aconstructor

func (zone Zone) Aconstructor(args ...any) Event

func (Zone) AconstructorError

func (zone Zone) AconstructorError(args ...any) Event

func (Zone) AconstructorErrorf

func (zone Zone) AconstructorErrorf(format string, v ...any) Event

func (Zone) Aconstructorf

func (zone Zone) Aconstructorf(format string, v ...any) Event

func (Zone) ArrowDown

func (zone Zone) ArrowDown(args ...any) Event

func (Zone) ArrowDownf

func (zone Zone) ArrowDownf(format string, v ...any) Event

func (Zone) ArrowIn

func (zone Zone) ArrowIn(args ...any) Event

func (Zone) ArrowInf

func (zone Zone) ArrowInf(format string, v ...any) Event

func (Zone) ArrowOut

func (zone Zone) ArrowOut(args ...any) Event

func (Zone) ArrowOutf

func (zone Zone) ArrowOutf(format string, v ...any) Event

func (Zone) ArrowUp

func (zone Zone) ArrowUp(args ...any) Event

func (Zone) ArrowUpf

func (zone Zone) ArrowUpf(format string, v ...any) Event

func (Zone) Bad

func (zone Zone) Bad(args ...any) Event

func (Zone) BadError

func (zone Zone) BadError(args ...any) Event

func (Zone) BadErrorf

func (zone Zone) BadErrorf(format string, v ...any) Event

func (Zone) Badf

func (zone Zone) Badf(format string, v ...any) Event

func (Zone) Build

func (zone Zone) Build(args ...any) Event

func (Zone) BuildError

func (zone Zone) BuildError(args ...any) Event

func (Zone) BuildErrorf

func (zone Zone) BuildErrorf(format string, v ...any) Event

func (Zone) Buildf

func (zone Zone) Buildf(format string, v ...any) Event

func (Zone) Check

func (zone Zone) Check(args ...any) Event

func (Zone) Checkf

func (zone Zone) Checkf(format string, v ...any) Event

func (Zone) Data

func (zone Zone) Data(args ...any) Event

func (Zone) DataError

func (zone Zone) DataError(args ...any) Event

func (Zone) DataErrorf

func (zone Zone) DataErrorf(format string, v ...any) Event

func (Zone) Dataf

func (zone Zone) Dataf(format string, v ...any) Event

func (Zone) Debug

func (zone Zone) Debug(args ...any) Event

func (Zone) Debugf

func (zone Zone) Debugf(format string, v ...any) Event

func (Zone) Decrypt

func (zone Zone) Decrypt(args ...any) Event

func (Zone) DecryptError

func (zone Zone) DecryptError(args ...any) Event

func (Zone) DecryptErrorf

func (zone Zone) DecryptErrorf(format string, v ...any) Event

func (Zone) Decryptf

func (zone Zone) Decryptf(format string, v ...any) Event

func (Zone) Default

func (zone Zone) Default() *log.Logger

func (Zone) Delete

func (zone Zone) Delete(args ...any) Event

func (Zone) DeleteError

func (zone Zone) DeleteError(args ...any) Event

func (Zone) DeleteErrorf

func (zone Zone) DeleteErrorf(format string, v ...any) Event

func (Zone) Deletef

func (zone Zone) Deletef(format string, v ...any) Event

func (Zone) Down

func (zone Zone) Down(args ...any) Event

func (Zone) DownError

func (zone Zone) DownError(args ...any) Event

func (Zone) DownErrorf

func (zone Zone) DownErrorf(format string, v ...any) Event

func (Zone) Downf

func (zone Zone) Downf(format string, v ...any) Event

func (Zone) Encrypt

func (zone Zone) Encrypt(args ...any) Event

func (Zone) EncryptError

func (zone Zone) EncryptError(args ...any) Event

func (Zone) EncryptErrorf

func (zone Zone) EncryptErrorf(format string, v ...any) Event

func (Zone) Encryptf

func (zone Zone) Encryptf(format string, v ...any) Event

func (Zone) Error

func (zone Zone) Error(args ...any) Event

func (Zone) Errorf

func (zone Zone) Errorf(format string, v ...any) Event

func (Zone) Fatal

func (zone Zone) Fatal(args ...any)

func (Zone) Fatalf

func (zone Zone) Fatalf(format string, v ...any)

func (Zone) Found

func (zone Zone) Found(args ...any) Event

func (Zone) Foundf

func (zone Zone) Foundf(format string, v ...any) Event

func (Zone) Function

func (zone Zone) Function(args ...any) Event

func (Zone) FunctionError

func (zone Zone) FunctionError(args ...any) Event

func (Zone) FunctionErrorf

func (zone Zone) FunctionErrorf(format string, v ...any) Event

func (Zone) Functionf

func (zone Zone) Functionf(format string, v ...any) Event

func (Zone) Good

func (zone Zone) Good(args ...any) Event

func (Zone) Goodf

func (zone Zone) Goodf(format string, v ...any) Event

func (Zone) In

func (zone Zone) In(args ...any) Event

func (Zone) InError

func (zone Zone) InError(args ...any) Event

func (Zone) InErrorf

func (zone Zone) InErrorf(format string, v ...any) Event

func (Zone) Inf

func (zone Zone) Inf(format string, v ...any) Event

func (Zone) Info

func (zone Zone) Info(args ...any) Event

func (Zone) Infof

func (zone Zone) Infof(format string, v ...any) Event

func (Zone) Init

func (zone Zone) Init(args ...any) Event

func (Zone) InitError

func (zone Zone) InitError(args ...any) Event

func (Zone) InitErrorf

func (zone Zone) InitErrorf(format string, v ...any) Event

func (Zone) Initf

func (zone Zone) Initf(format string, v ...any) Event

func (Zone) Input

func (zone Zone) Input(args ...any) Event

func (Zone) InputError

func (zone Zone) InputError(args ...any) Event

func (Zone) InputErrorf

func (zone Zone) InputErrorf(format string, v ...any) Event

func (Zone) Inputf

func (zone Zone) Inputf(format string, v ...any) Event

func (Zone) Key

func (zone Zone) Key(args ...any) Event

func (Zone) KeyError

func (zone Zone) KeyError(args ...any) Event

func (Zone) KeyErrorf

func (zone Zone) KeyErrorf(format string, v ...any) Event

func (Zone) Keyf

func (zone Zone) Keyf(format string, v ...any) Event

func (Zone) Line

func (zone Zone) Line(args ...any) Event

func (Zone) LineError

func (zone Zone) LineError(args ...any) Event

func (Zone) LineErrorf

func (zone Zone) LineErrorf(format string, v ...any) Event

func (Zone) Linef

func (zone Zone) Linef(format string, v ...any) Event

func (Zone) N

func (zone Zone) N(name string) Zone

N changes zone name and can be used, for example, to temporary change the current event name:

zone.N("foo").Info("bar")

func (Zone) NewEvent

func (zone Zone) NewEvent(emoji string, isError bool, args ...any) Event

func (Zone) NotFound

func (zone Zone) NotFound(args ...any) Event

func (Zone) NotFoundf

func (zone Zone) NotFoundf(format string, v ...any) Event

func (Zone) Ok

func (zone Zone) Ok(args ...any) Event

func (Zone) Okf

func (zone Zone) Okf(format string, v ...any) Event

func (Zone) Out

func (zone Zone) Out(args ...any) Event

func (Zone) OutError

func (zone Zone) OutError(args ...any) Event

func (Zone) OutErrorf

func (zone Zone) OutErrorf(format string, v ...any) Event

func (Zone) Outf

func (zone Zone) Outf(format string, v ...any) Event

func (Zone) Output

func (zone Zone) Output(args ...any) Event

func (Zone) OutputError

func (zone Zone) OutputError(args ...any) Event

func (Zone) OutputErrorf

func (zone Zone) OutputErrorf(format string, v ...any) Event

func (Zone) Outputf

func (zone Zone) Outputf(format string, v ...any) Event

func (Zone) Panic

func (zone Zone) Panic(args ...any)

func (Zone) Panicf

func (zone Zone) Panicf(format string, v ...any)

func (Zone) Param

func (zone Zone) Param(args ...any) Event

func (Zone) ParamError

func (zone Zone) ParamError(args ...any) Event

func (Zone) ParamErrorf

func (zone Zone) ParamErrorf(format string, v ...any) Event

func (Zone) Paramf

func (zone Zone) Paramf(format string, v ...any) Event

func (Zone) Print

func (zone Zone) Print(args ...any) Event

func (Zone) Printf

func (zone Zone) Printf(format string, v ...any) Event

func (Zone) Query

func (zone Zone) Query(args ...any) Event

func (Zone) QueryError

func (zone Zone) QueryError(args ...any) Event

func (Zone) QueryErrorf

func (zone Zone) QueryErrorf(format string, v ...any) Event

func (Zone) Queryf

func (zone Zone) Queryf(format string, v ...any) Event

func (Zone) RefreshToken

func (zone Zone) RefreshToken(args ...any) Event

func (Zone) RefreshTokenf

func (zone Zone) RefreshTokenf(format string, v ...any) Event

func (Zone) RequestGet

func (zone Zone) RequestGet(args ...any) Event

func (Zone) RequestGetError

func (zone Zone) RequestGetError(args ...any) Event

func (Zone) RequestGetErrorf

func (zone Zone) RequestGetErrorf(format string, v ...any) Event

func (Zone) RequestGetf

func (zone Zone) RequestGetf(format string, v ...any) Event

func (Zone) RequestPost

func (zone Zone) RequestPost(args ...any) Event

func (Zone) RequestPostError

func (zone Zone) RequestPostError(args ...any) Event

func (Zone) RequestPostErrorf

func (zone Zone) RequestPostErrorf(format string, v ...any) Event

func (Zone) RequestPostf

func (zone Zone) RequestPostf(format string, v ...any) Event

func (Zone) Result

func (zone Zone) Result(args ...any) Event

func (Zone) Resultf

func (zone Zone) Resultf(format string, v ...any) Event

func (Zone) S

func (zone Zone) S(callDepth ...int) Zone

S controls the printing of the call stack information. Without arguments, S forces the retrieval of the call stack info (i.e. caller function and file:line).

The call stack depth can be shifted with the optional parameter:

func myLoggerFunction(s string) { zone.S(2).Error(s) }

S can also be used to disable the call stack info using a negative value:

zone.S(-1).Error("msg")

The zero value is to use the global settings:

zone.S(0).Error("msg")

func (Zone) Save

func (zone Zone) Save(args ...any) Event

func (Zone) SaveError

func (zone Zone) SaveError(args ...any) Event

func (Zone) SaveErrorf

func (zone Zone) SaveErrorf(format string, v ...any) Event

func (Zone) Savef

func (zone Zone) Savef(format string, v ...any) Event

func (Zone) Security

func (zone Zone) Security(args ...any) Event

func (Zone) SecurityError

func (zone Zone) SecurityError(args ...any) Event

func (Zone) SecurityErrorf

func (zone Zone) SecurityErrorf(format string, v ...any) Event

func (Zone) Securityf

func (zone Zone) Securityf(format string, v ...any) Event

func (Zone) SetHook

func (zone Zone) SetHook(hook func(Event)) Zone

SetHook sets the callback function to be triggered when an Event occurs.

func (Zone) SmallArrowDown

func (zone Zone) SmallArrowDown(args ...any) Event

func (Zone) SmallArrowDownf

func (zone Zone) SmallArrowDownf(format string, v ...any) Event

func (Zone) SmallArrowIn

func (zone Zone) SmallArrowIn(args ...any) Event

func (Zone) SmallArrowInf

func (zone Zone) SmallArrowInf(format string, v ...any) Event

func (Zone) SmallArrowOut

func (zone Zone) SmallArrowOut(args ...any) Event

func (Zone) SmallArrowOutf

func (zone Zone) SmallArrowOutf(format string, v ...any) Event

func (Zone) SmallArrowUp

func (zone Zone) SmallArrowUp(args ...any) Event

func (Zone) SmallArrowUpf

func (zone Zone) SmallArrowUpf(format string, v ...any) Event

func (Zone) Start

func (zone Zone) Start(args ...any) Event

func (Zone) StartError

func (zone Zone) StartError(args ...any) Event

func (Zone) StartErrorf

func (zone Zone) StartErrorf(format string, v ...any) Event

func (Zone) Startf

func (zone Zone) Startf(format string, v ...any) Event

func (Zone) State

func (zone Zone) State(args ...any) Event

func (Zone) StateError

func (zone Zone) StateError(args ...any) Event

func (Zone) StateErrorf

func (zone Zone) StateErrorf(format string, v ...any) Event

func (Zone) Statef

func (zone Zone) Statef(format string, v ...any) Event

func (Zone) Stop

func (zone Zone) Stop(args ...any) Event

func (Zone) StopError

func (zone Zone) StopError(args ...any) Event

func (Zone) StopErrorf

func (zone Zone) StopErrorf(format string, v ...any) Event

func (Zone) Stopf

func (zone Zone) Stopf(format string, v ...any) Event

func (Zone) Time

func (zone Zone) Time(args ...any) Event

func (Zone) TimeError

func (zone Zone) TimeError(args ...any) Event

func (Zone) TimeErrorf

func (zone Zone) TimeErrorf(format string, v ...any) Event

func (Zone) Timef

func (zone Zone) Timef(format string, v ...any) Event

func (Zone) Trace

func (zone Zone) Trace(args ...any) Event

func (Zone) Tracef

func (zone Zone) Tracef(format string, v ...any) Event

func (Zone) Transmit

func (zone Zone) Transmit(args ...any) Event

func (Zone) TransmitError

func (zone Zone) TransmitError(args ...any) Event

func (Zone) TransmitErrorf

func (zone Zone) TransmitErrorf(format string, v ...any) Event

func (Zone) Transmitf

func (zone Zone) Transmitf(format string, v ...any) Event

func (Zone) Up

func (zone Zone) Up(args ...any) Event

func (Zone) UpError

func (zone Zone) UpError(args ...any) Event

func (Zone) UpErrorf

func (zone Zone) UpErrorf(format string, v ...any) Event

func (Zone) Update

func (zone Zone) Update(args ...any) Event

func (Zone) UpdateError

func (zone Zone) UpdateError(args ...any) Event

func (Zone) UpdateErrorf

func (zone Zone) UpdateErrorf(format string, v ...any) Event

func (Zone) Updatef

func (zone Zone) Updatef(format string, v ...any) Event

func (Zone) Upf

func (zone Zone) Upf(format string, v ...any) Event

func (Zone) V

func (zone Zone) V(auto ...bool) Zone

SetVerbosity controls the verbose mode. When used with DefaultZone, it impacts all zones having Verbose=Auto. V forces the event to be always printed, even when zone.Verbose=false.

V can also be used to never print the log. Example:

zone.V(false).Error("my error")

func (Zone) Warn

func (zone Zone) Warn(args ...any) Event

Warn looks same as Warning, but:

  • Warn is printed even when Verbose=No, and
  • Warn is printed with the call stack info (similar to Error).

func (Zone) Warnf

func (zone Zone) Warnf(format string, v ...any) Event

func (Zone) Warning

func (zone Zone) Warning(args ...any) Event

func (Zone) Warningf

func (zone Zone) Warningf(format string, v ...any) Event

Directories

Path Synopsis
doc
ts
examples
go command

Jump to